@@ -1,7 +1,7 @@
 ################################################################################
 
 message2 <- function(...) message(sprintf(...))
-# warning2 <- function(...) warning(sprintf(...), call. = FALSE)
+warning2 <- function(...) warning(sprintf(...), call. = FALSE)
 stop2    <- function(...) stop(sprintf(...), call. = FALSE)
 
 ################################################################################
